Ansi class

Helper class to assist in printing text to the console with a color.

Use one of the color functions instead of this class.

See:

Constructors

Ansi()
Factory ctor
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isSupported ↔ bool
returns true if stdout supports ansi escape characters.
getter/setter pair
resetEmitAnsi → void
If you have called isSupported then calling resetEmitAnsi will reset the emit setting to the default detected.
no setter

Static Methods

strip(String line) → String
Strip all ansi escape sequences from line.

Constants

esc → const String
ANSI Control Sequence Introducer, signals the terminal for new settings.