ArgResults class

The results of parsing a series of command line arguments using ArgParser.parse.

Includes the parsed options and any remaining unparsed command line arguments.

Available extensions

Properties

arguments → List<String>
The original arguments that were parsed.
final
command → ArgResults?
The command that was selected, or null if none was.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the command for which these options are parsed, or null if these are the top-level results.
final
options → Iterable<String>
The names of the available options.
no setter
rest → List<String>
The remaining command-line arguments that were not parsed as options or flags.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

flag(String name) → bool
Returns the parsed or default command-line flag named name.
getFlagCodesign() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getFlagDebug() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

getFlagObfuscate() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getFlagProfile() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

getFlagQa() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

getFlagRelease() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

getMode() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionBuildName() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionBuildNumber() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionDriver() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionExportMethod() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionExportOptionsPlist() → String?

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionFlavor({required String defaultTo}) → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionGitsYaml() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionScreenshot() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionSplitDebugInfo() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionTarget() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

getOptionUseApp() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

multiOption(String name) → List<String>
Returns the list of parsed (or default) command-line options for name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option(String name) → String?
Returns the parsed or default command-line option named name.
toString() → String
A string representation of this object.
inherited
wasParsed(String name) → bool
Returns true if the option with name was parsed from an actual argument.

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String name) → dynamic
Returns the parsed or default command-line option named name.