DCliException class

Base class for all DCli exceptions.

Implemented types

Constructors

DCliException(String message, [Trace? stackTrace])
DCliException.from(Object? cause, Trace stackTrace)
DCliException.fromException(Object? cause)
DCliException.fromJson(String jsonStr)
factory

Properties

cause → Object?
If DCliException is wrapping another exception then this is the exeception that is wrapped.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ Trace
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printStackTrace() → void
toJson() → Map<String, dynamic>
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited