DCliPaths class

platform specific names of the dcli commands.

Constructors

DCliPaths()
factory

Properties

dcliCompleteName ↔ String
platform specific name of the dcli auto complete command
latefinal
dcliInstallName ↔ String
platform specific name of the dcli install command
latefinal
dcliName ↔ String
platform specific name of the dcli command
latefinal
hashCode → int
The hash code for this object.
no setterinherited
pathToDCli → String?
Returns the path to the DCli executable. Returns null if DCli is not on the path.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited