FetchStatus enum

Used by FetchProgress to indicate the progress of a download.

Inheritance
Available extensions

Values

initialising → const FetchStatus

we are preparing to download. You will always see one and only one instance of this status in a FetchProgress event. In most cases the fetch will only stay in this state for a moment.

connecting → const FetchStatus

We have stated the process of connecting to the remote resource.

connected → const FetchStatus

We have connected to the remote server.

response → const FetchStatus

After connection we get a responseCode.

headers → const FetchStatus

Called when we recieve the headersafter we connect.

downloading → const FetchStatus

we have connected and recieved our first chunk of data.

complete → const FetchStatus

the download is complete.

error → const FetchStatus

An error occured whilst attempting to fetch the resource. All fetch operations will cease an an FetchException will be thrown.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<FetchStatus>
A constant List of the values in this enum, in order of their declaration.