FetchUrl class

Used to describe a url that is being downloaded including the location where it is going to be stored.

Constructors

FetchUrl({required String url, required String saveToPath, Map<String, String>? headers, FetchMethod method = FetchMethod.get, OnFetchProgress progress = _devNull, FetchData? data})
ctor.

Properties

data ↔ FetchData?
For FetchMethods that allow you to send data such as FetchMethod.post this holds the data that is to be sent.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>
The set of HTTP headers to send with the request.
latefinal
method → FetchMethod
the HTTP method to use when sending the url Defaults to get.
final
progress → OnFetchProgress
If provided this is the callback to allow the caller to monitor the download progress.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveToPath → String
The path to the file the download will be saved to.
final
url → String
the URL of the resource being downloaded
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited