PackedResource class abstract

Base class used by all PackedResources.

Constructors

PackedResource()
Create a PackedResource with the given b64encoded content.
const

Properties

checksum → String
The checksum of the original file. You can use this value to see if packed file is different to a local file without having to unpack it.
no setter
content → String
The base64 encoded contents of the packed file.
no setter
hashCode → int
The hash code for this object.
no setterinherited
originalPath → String
The path to the original file relative to the packages resource directory.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unpack(String pathTo) → void
Unpacks a resource saving it to the file at pathTo.

Operators

operator ==(Object other) → bool
The equality operator.
inherited