PathException class

An exception class that's thrown when a path operation is unable to be computed accurately.

Implemented types

Constructors

PathException(String message)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited