PathSet class

A set containing paths, compared using p.equals and p.hash.

Inheritance
Implemented types

Constructors

PathSet({Context? context})
Creates an empty PathSet whose contents are compared using context.equals and context.hash.
PathSet.of(Iterable<String> other, {Context? context})
Creates a PathSet with the same contents as other whose elements are compared using context.equals and context.hash.

Properties

first → String?
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<String?>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → String?
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → String?
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

add(String? value) → bool
Adds value to the set.
override
addAll(Iterable<String?> elements) → void
Adds all elements to this set.
override
any(bool test(String? value)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<T>() → Set<T>
A view of this iterable as an iterable of R instances.
override
clear() → void
Removes all elements from the set.
override
contains(Object? element) → bool
Whether the collection contains an element equal to element.
override
containsAll(Iterable<Object?> other) → bool
Whether this set contains all the elements of other.
override
difference(Set<Object?> other) → Set<String?>
Creates a new set with the elements of this that are not in other.
override
elementAt(int index) → String?
Returns the indexth element.
inherited
every(bool test(String? value)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(String? element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(String? value), {String? orElse()?}) → String?
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, String? element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<String?> other) → Iterable<String?>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(String? element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
intersection(Set<Object?> other) → Set<String?>
Creates a new set which is the intersection between this set and other.
override
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(String? value), {String? orElse()?}) → String?
The last element that satisfies the given predicate test.
inherited
lookup(Object? element) → String?
If an object equal to object is in the set, return it.
override
map<T>(T toElement(String? e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(String? combine(String? value, String? element)) → String?
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(Object? value) → bool
Removes value from the set.
override
removeAll(Iterable<Object?> elements) → void
Removes each element of elements from this set.
override
removeWhere(bool test(String? value)) → void
Removes all elements of this set that satisfy test.
override
retainAll(Iterable<Object?> elements) → void
Removes all elements of this set that are not elements in elements.
override
retainWhere(bool test(String? value)) → void
Removes all elements of this set that fail to satisfy test.
override
singleWhere(bool test(String? value), {String? orElse()?}) → String?
The single element that satisfies test.
inherited
skip(int count) → Iterable<String?>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(String? value)) → Iterable<String?>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<String?>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(String? value)) → Iterable<String?>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<String?>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<String?>
Creates a Set containing the same elements as this iterable.
override
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
union(Set<String?> other) → Set<String?>
Creates a new set which contains all the elements of this set and other.
override
where(bool test(String? value)) → Iterable<String?>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited