RunException class

Thrown when any of the process related method such as .run and .start fail.

Inheritance

Constructors

RunException(String cmdLine, int? exitCode, String reason, {Trace? stackTrace})
RunException.fromException(Object exception, String? cmd, List<String?> args, {Trace? stackTrace})
RunException.fromJson(Map<String, dynamic> json)
RunException.fromJsonString(String jsonString)
factory
RunException.withArgs(String? cmd, List<String?> args, int? exitCode, String reason, {Trace? stackTrace})

Properties

cause → Object?
If DCliException is wrapping another exception then this is the exeception that is wrapped.
finalinherited
cmdLine ↔ String
The command line that was being run.
getter/setter pair
exitCode ↔ int?
the exit code of the command.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message → String
no setteroverride
reason ↔ String
the error.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ Trace
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printStackTrace() → void
inherited
toJson() → Map<String, dynamic>
inherited
toJsonMap() → Map<String, dynamic>
toJsonString() → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited