Style class abstract

An enum type describing a "flavor" of path.

Constructors

Style()

Properties

context → Context
A Context that uses this style.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of this path style. Will be "posix" or "windows".
no setter
needsSeparatorPattern → Pattern
no setter
relativeRootPattern → Pattern?
no setter
rootPattern → Pattern
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separator → String
no setter
separatorPattern → Pattern
no setter

Methods

absolutePathToUri(String path) → Uri
getRelativeRoot(String path) → String?
getRoot(String path) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathFromUri(Uri uri) → String
relativePathToUri(String path) → Uri
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

platform → Style
The style of the host platform.
final
posix → Style
POSIX-style paths use "/" (forward slash) as separators. Absolute paths start with "/". Used by UNIX, Linux, Mac OS X, and others.
final
url → Style
URLs aren't filesystem paths, but they're supported to make it easier to manipulate URL paths in the browser.
final
windows → Style
Windows paths use \ (backslash) as separators. Absolute paths start with a drive letter followed by a colon (example, C:) or two backslashes (\\) for UNC paths.
final