TagDirective class

A directive describing a custom tag handle.

Constructors

TagDirective(String handle, String prefix)

Properties

handle → String
The handle for use in the document.
final
hashCode → int
The hash code for this object.
no setterinherited
prefix → String
The prefix that the handle maps to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited