TemplateNotFoundException class

The requested DCli template does not exists.

Inheritance

Constructors

TemplateNotFoundException(String pathTo)
The requested DCli template does not exists.

Properties

cause → Object?
If DCliException is wrapping another exception then this is the exeception that is wrapped.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ Trace
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printStackTrace() → void
inherited
toJson() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited