VersionDirective class

A directive indicating which version of YAML a document was written to.

Constructors

VersionDirective(int major, int minor)

Properties

hashCode → int
The hash code for this object.
no setterinherited
major → int
The major version number.
final
minor → int
The minor version number.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited