YamlDocument class

A YAML document, complete with metadata.

Constructors

YamlDocument.internal(YamlNode contents, SourceSpan span, VersionDirective? versionDirective, List<TagDirective> tagDirectives, {bool startImplicit = false, bool endImplicit = false})
Users of the library should not use this constructor.

Properties

contents → YamlNode
The contents of the document.
final
endImplicit → bool
Whether the end of the document was implicit (versus explicit via ...).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan
The span covering the entire document.
final
startImplicit → bool
Whether the beginning of the document was implicit (versus explicit via ===).
final
tagDirectives → List<TagDirective>
The tag directives for the document.
final
versionDirective → VersionDirective?
The version directive for the document, if any.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited