YamlMap class

A read-only Map parsed from YAML.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

YamlMap({Object? sourceUrl})
Creates an empty YamlMap.
factory
YamlMap.internal(Map<dynamic, YamlNode> nodes, SourceSpan span, CollectionStyle style)
Users of the library should not use this constructor.
YamlMap.wrap(Map dartMap, {Object? sourceUrl, CollectionStyle style = CollectionStyle.ANY})
Wraps a Dart map so that it can be accessed (recursively) like a YamlMap.
factory

Properties

concurrent → int

Available on Map, provided by the MapYamlExtension extension

no setter
entries → Iterable<MapEntry>
The map entries of this Map.
no setterinherited
first ← dynamic
Throws an UnsupportedError; operations that change the map are disallowed.
no getterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable
The keys of this Map.
no setteroverride
last ← dynamic
Throws an UnsupportedError; operations that change the map are disallowed.
no getterinherited
length → int
The number of key/value pairs in the map.
no setterinherited
nodes → Map<dynamic, YamlNode>
A view of this where the keys and values are guaranteed to be YamlNodes.
final
projectName → String

Available on Map, provided by the MapYamlExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → SourceSpan
The source span for this node.
no setterinherited
style → CollectionStyle
The style used for the map in the original document.
final
value → Map
The inner value of this node.
no setteroverride
values → Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map other) → void
Throws an UnsupportedError; operations that change the map are disallowed.
inherited
addEntries(Iterable<MapEntry> newEntries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<RK, RV>() → Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Throws an UnsupportedError; operations that change the map are disallowed.
inherited
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
forEach(void action(dynamic key, dynamic value)) → void
Applies action to each key/value pair of the map.
inherited
map<K2, V2>(MapEntry<K2, V2> transform(dynamic key, dynamic value)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(dynamic key, dynamic ifAbsent()) → dynamic
Throws an UnsupportedError; operations that change the map are disallowed.
inherited
remove(Object? key) → dynamic
Throws an UnsupportedError; operations that change the map are disallowed.
inherited
removeWhere(bool test(dynamic key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
inherited
toString() → String
A string representation of this object.
inherited
update(dynamic key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(dynamic key, dynamic value)) → void
Updates all values.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
override
operator []=(dynamic key, dynamic value) → void
Throws an UnsupportedError; operations that change the map are disallowed.
inherited