FlutterHelper class abstract

Constructors

FlutterHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getCommandDart() → String
getCommandFlutter() → String
run(String argument, {bool showLog = false}) → void
start(String argument, {bool showLog = false, String? workingDirectory, Progress? progress}) → void