LocalizationHelper class

Constructors

LocalizationHelper(String pathGitsyaml)

Properties

arbDir → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
outputClass → String
no setter
outputDir → String
no setter
outputLocalizationFile → String
no setter
replace → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateArbFile → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited